RLtools: A Fast, Portable Deep Reinforcement Learning Library for Continuous Control

### : A Fast, Portable Deep Reinforcement Learning Library for Continuous Control

Paper on arXiv Documentation Code on Github
Realtime
Your browser does not support the video tag.
Trained on a 2020 MacBook Pro (M1) using RLtools PPO
In the previous example the Pendulum-v1 swingup is trained directly in your browser using the SAC deep reinforcement learning algorithm. RLtools is a pure C++ header-only, dependency free deep supervised- and reinforcmeent learning library that runs on a broad variety of devices (as e.g. your browser). To run it in a browser the C++ code is compiled to WASM which can be called from JavaScript. For more information read the paper and/or the source code (both linked on top of the page).

    Terminal Output

### Interactive Example: Racing Car (PPO)